# Time

```{eval-rst}
.. currentmodule:: kaskada

.. autosummary::
   :toctree: ../apidocs/

    Timestream.shift_by
    Timestream.shift_to
    Timestream.shift_until
    Timestream.time
    Timestream.seconds_since
    Timestream.seconds_since_previous
```